/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: getcatalogstr.c,v 1.5 2012/12/20 19:28:18 itix Exp $

    Desc:
    Lang: english
*/

#include <exec/types.h>
#include <proto/btree.h>
#include <proto/exec.h>
#include "locale_intern.h"

/*****************************************************************************

    NAME */
#include <proto/locale.h>

	AROS_LH3(STRPTR, GetCatalogStr,

/*  SYNOPSIS */
	AROS_LHA(struct Catalog *, catalog, A0),
	AROS_LHA(ULONG           , stringNum, D0),	/* Not a typo! Needs to be unsigned for ICF_INORDER */
	AROS_LHA(STRPTR          , defaultString, A1),

/*  LOCATION */
	struct LocaleBase *, LocaleBase, 12, Locale)

/* ---- locale.library/GetCatalogStr ----
 *
 *   NAME   
 *        GetCatalogStr -- get a localized string from a catalog
 *
 *   SYNOPSIS
 *        string = GetCatalogStr(catalog, stringNum, defaultString);
 *
 *        CONST_STRPTR GetCatalogStr(struct Catalog *, LONG, CONST_STRPTR);
 *
 *   FUNCTION
 *        This function will return the string specified by the
 *        stringNum from the given message catalog, or the defaultString
 *        if the string could not be found.
 *
 *        If the catalog == NULL, then the defaultString will also be
 *        returned.
 *
 *   INPUTS
 *        catalog       - Message catalog to search. May be NULL.
 *        stringNum     - ID of the string to find.
 *        defaultString - String to return in case catalog is NULL or
 *                        string could not be found.
 *
 *   RESULT
 *        A pointer to a READ ONLY NULL terminated string. This string
 *        pointer is valid as long as the catalog remains open.
 *
 *   SEE ALSO
 *        OpenCatalogA(), CloseCatalog()
 *
 */
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct Library *,LocaleBase)
    STRPTR str = defaultString;
	struct IntCatalog *cat = (APTR)catalog;

	if (catalog != NULL && catalog->cat_CodeSet != CODESET_UTF32 && cat->ic_CatTree)
	{
		GETTREEBASE(LocaleBase);

		APTR node = FindTreeNodeByKey(cat->ic_CatTree, (APTR)stringNum);

		if (node)
			str = GetTreeNodeData(cat->ic_CatTree, node);
	}

    return str;

    AROS_LIBFUNC_EXIT

} /* GetCatalogStr */
